@@ -7,6 +7,8 @@ try:
 except ImportError:
     apps = None
 from django.db import models, router
+from django.db.models import loading
+from django.db.models.fields.proxy import OrderWrt
 from django.db.models.fields.related import RelatedField
 from django.db.models.related import RelatedObject
 from django.conf import settings
@@ -23,6 +25,13 @@ except ImportError:
     from datetime import datetime
     now = datetime.now
 from django.utils.translation import string_concat
+try:
+    from south.modelsinspector import add_introspection_rules
+except ImportError:
+    pass
+else:
+    add_introspection_rules(
+        [], ["^simple_history.models.CustomForeignKeyField"])
 from .manager import HistoryDescriptor
 
 registered_models = {}
@@ -93,7 +102,7 @@ class HistoricalRecords(object):
         elif app_module != self.module:
             if apps is None:
                 # has meta options with app_label
-                app = models.get_app(model._meta.app_label)
+                app = loading.get_app(model._meta.app_label)
                 attrs['__module__'] = app.__name__  # full dotted name
             else:
                 # Abuse an internal API because the app registry is loading.
@@ -127,6 +136,9 @@ class HistoricalRecords(object):
                 field.rel.related_name = '+'
                 field.null = True
                 field.blank = True
+            if isinstance(field, OrderWrt):
+                # OrderWrt is a proxy field, switch to a plain IntegerField
+                field.__class__ = models.IntegerField
             transform_field(field)
             fields[field.name] = field
         return fields
@@ -141,9 +153,9 @@ class HistoricalRecords(object):
             """URL for this change in the default admin site."""
             opts = model._meta
             try:
-                app_label, model_name = opts.app_label, opts.module_name
-            except AttributeError:
                 app_label, model_name = opts.app_label, opts.model_name
+            except AttributeError:
+                app_label, model_name = opts.app_label, opts.module_name
             return ('%s:%s_%s_simple_history' %
                     (admin.site.name, app_label, model_name),
                     [getattr(self, opts.pk.attname), self.history_id])
@@ -194,14 +206,14 @@ class HistoricalRecords(object):
     def post_delete(self, instance, **kwargs):
         self.create_historical_record(instance, '-')
 
-    def create_historical_record(self, instance, type):
+    def create_historical_record(self, instance, history_type):
         history_date = getattr(instance, '_history_date', now())
         history_user = self.get_history_user(instance)
         manager = getattr(instance, self.manager_name)
         attrs = {}
         for field in instance._meta.fields:
             attrs[field.attname] = getattr(instance, field.attname)
-        manager.create(history_date=history_date, history_type=type,
+        manager.create(history_date=history_date, history_type=history_type,
                        history_user=history_user, **attrs)
 
     def get_history_user(self, instance):
@@ -286,8 +298,7 @@ class CustomForeignKeyField(models.ForeignKey):
             try:
                 instance_type = cls.instance_type
             except AttributeError:  # when model is reconstituted for migration
-                if cls.__module__ != "__fake__":  # not from migrations, error
-                    raise
+                pass  # happens during migrations
             else:
                 self.related = RelatedObject(other, instance_type, self)
         transform_field(field)
